aboutsummaryrefslogtreecommitdiffstats
path: root/pySim-shell.py
diff options
context:
space:
mode:
authorHarald Welte <laforge@osmocom.org>2024-01-15 09:21:03 +0100
committerHarald Welte <laforge@osmocom.org>2024-01-16 19:04:10 +0100
commitcd18ed0a82403bc8d4d36649d56bc5e5ee5676d4 (patch)
tree1c9a6c122b70aa0bb2959d57fd653595cc634d1b /pySim-shell.py
parentecfb09037e4dbad54b06bacaa43aa6015f769593 (diff)
ts_102_221: Better explain 'selected file invalidated'
Some specs call it 'invalidated', others call it 'deactivated'. If the user is unfamiliar with this, the error message about "invalidated" might not be obvious enough; let's also mention 'deactivated' in the message and explicitly mention that it needs to be activated before use. Change-Id: I91488b0e7dc25a8970022b09e575485a4165eefa
Diffstat (limited to 'pySim-shell.py')
-rwxr-xr-xpySim-shell.py11
1 files changed, 9 insertions, 2 deletions
diff --git a/pySim-shell.py b/pySim-shell.py
index 6ff484b..c645403 100755
--- a/pySim-shell.py
+++ b/pySim-shell.py
@@ -882,8 +882,15 @@ class Iso7816Commands(CommandSet):
activate_file_parser.add_argument('NAME', type=str, help='File name or FID of file to activate')
@cmd2.with_argparser(activate_file_parser)
def do_activate_file(self, opts):
- """Activate the specified EF. This used to be called REHABILITATE in TS 11.11 for classic
- SIM. You need to specify the name or FID of the file to activate."""
+ """Activate the specified EF by sending an ACTIVATE FILE apdu command (used to be called REHABILITATE
+in TS 11.11 for classic SIM).
+
+This command is used to (re-)activate a file that is currently in deactivated (sometimes also called
+"invalidated") state. You need to call this from the DF above the to-be-activated EF and specify the name or
+FID of the file to activate.
+
+Note that for *deactivation* the to-be-deactivated EF must be selected, but for *activation*, the DF
+above the to-be-activated EF must be selected!"""
(data, sw) = self._cmd.lchan.activate_file(opts.NAME)
def complete_activate_file(self, text, line, begidx, endidx) -> List[str]: